"""SimpleNode"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private import _0
from mastapy._private._internal import conversion, utility
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_method_call,
    pythonnet_property_get,
)
from mastapy._private._internal.type_enforcement import enforce_parameter_types

_SIMPLE_NODE = python_net_import(
    "SMT.MastaAPI.NodalAnalysis.LumpedParameterThermalAnalysis", "SimpleNode"
)

if TYPE_CHECKING:
    from typing import Any, List, Type, TypeVar

    from mastapy._private.nodal_analysis.lumped_parameter_thermal_analysis import (
        _174,
        _175,
        _179,
        _192,
        _195,
        _205,
        _206,
        _207,
        _221,
    )

    Self = TypeVar("Self", bound="SimpleNode")
    CastSelf = TypeVar("CastSelf", bound="SimpleNode._Cast_SimpleNode")


__docformat__ = "restructuredtext en"
__all__ = ("SimpleNode",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_SimpleNode:
    """Special nested class for casting SimpleNode to subclasses."""

    __parent__: "SimpleNode"

    @property
    def auto_generated_simple_fluid_thermal_node(
        self: "CastSelf",
    ) -> "_174.AutoGeneratedSimpleFluidThermalNode":
        from mastapy._private.nodal_analysis.lumped_parameter_thermal_analysis import (
            _174,
        )

        return self.__parent__._cast(_174.AutoGeneratedSimpleFluidThermalNode)

    @property
    def auto_generated_simple_thermal_node(
        self: "CastSelf",
    ) -> "_175.AutoGeneratedSimpleThermalNode":
        from mastapy._private.nodal_analysis.lumped_parameter_thermal_analysis import (
            _175,
        )

        return self.__parent__._cast(_175.AutoGeneratedSimpleThermalNode)

    @property
    def channel_face_thermal_node(self: "CastSelf") -> "_179.ChannelFaceThermalNode":
        from mastapy._private.nodal_analysis.lumped_parameter_thermal_analysis import (
            _179,
        )

        return self.__parent__._cast(_179.ChannelFaceThermalNode)

    @property
    def face_node(self: "CastSelf") -> "_192.FaceNode":
        from mastapy._private.nodal_analysis.lumped_parameter_thermal_analysis import (
            _192,
        )

        return self.__parent__._cast(_192.FaceNode)

    @property
    def fe_simple_thermal_node(self: "CastSelf") -> "_195.FESimpleThermalNode":
        from mastapy._private.nodal_analysis.lumped_parameter_thermal_analysis import (
            _195,
        )

        return self.__parent__._cast(_195.FESimpleThermalNode)

    @property
    def simple_thermal_node(self: "CastSelf") -> "_205.SimpleThermalNode":
        from mastapy._private.nodal_analysis.lumped_parameter_thermal_analysis import (
            _205,
        )

        return self.__parent__._cast(_205.SimpleThermalNode)

    @property
    def simple_thermal_node_base(self: "CastSelf") -> "_206.SimpleThermalNodeBase":
        from mastapy._private.nodal_analysis.lumped_parameter_thermal_analysis import (
            _206,
        )

        return self.__parent__._cast(_206.SimpleThermalNodeBase)

    @property
    def simple_volumetric_flow_rate_node(
        self: "CastSelf",
    ) -> "_207.SimpleVolumetricFlowRateNode":
        from mastapy._private.nodal_analysis.lumped_parameter_thermal_analysis import (
            _207,
        )

        return self.__parent__._cast(_207.SimpleVolumetricFlowRateNode)

    @property
    def user_defined_simple_thermal_node(
        self: "CastSelf",
    ) -> "_221.UserDefinedSimpleThermalNode":
        from mastapy._private.nodal_analysis.lumped_parameter_thermal_analysis import (
            _221,
        )

        return self.__parent__._cast(_221.UserDefinedSimpleThermalNode)

    @property
    def simple_node(self: "CastSelf") -> "SimpleNode":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class SimpleNode(_0.APIBase):
    """SimpleNode

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _SIMPLE_NODE

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def report_names(self: "Self") -> "List[str]":
        """List[str]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ReportNames")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp, str)

        if value is None:
            return None

        return value

    @enforce_parameter_types
    def output_default_report_to(self: "Self", file_path: "str") -> None:
        """Method does not return.

        Args:
            file_path (str)
        """
        file_path = str(file_path)
        pythonnet_method_call(
            self.wrapped, "OutputDefaultReportTo", file_path if file_path else ""
        )

    def get_default_report_with_encoded_images(self: "Self") -> "str":
        """str"""
        method_result = pythonnet_method_call(
            self.wrapped, "GetDefaultReportWithEncodedImages"
        )
        return method_result

    @enforce_parameter_types
    def output_active_report_to(self: "Self", file_path: "str") -> None:
        """Method does not return.

        Args:
            file_path (str)
        """
        file_path = str(file_path)
        pythonnet_method_call(
            self.wrapped, "OutputActiveReportTo", file_path if file_path else ""
        )

    @enforce_parameter_types
    def output_active_report_as_text_to(self: "Self", file_path: "str") -> None:
        """Method does not return.

        Args:
            file_path (str)
        """
        file_path = str(file_path)
        pythonnet_method_call(
            self.wrapped, "OutputActiveReportAsTextTo", file_path if file_path else ""
        )

    def get_active_report_with_encoded_images(self: "Self") -> "str":
        """str"""
        method_result = pythonnet_method_call(
            self.wrapped, "GetActiveReportWithEncodedImages"
        )
        return method_result

    @enforce_parameter_types
    def output_named_report_to(
        self: "Self", report_name: "str", file_path: "str"
    ) -> None:
        """Method does not return.

        Args:
            report_name (str)
            file_path (str)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        pythonnet_method_call(
            self.wrapped,
            "OutputNamedReportTo",
            report_name if report_name else "",
            file_path if file_path else "",
        )

    @enforce_parameter_types
    def output_named_report_as_masta_report(
        self: "Self", report_name: "str", file_path: "str"
    ) -> None:
        """Method does not return.

        Args:
            report_name (str)
            file_path (str)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        pythonnet_method_call(
            self.wrapped,
            "OutputNamedReportAsMastaReport",
            report_name if report_name else "",
            file_path if file_path else "",
        )

    @enforce_parameter_types
    def output_named_report_as_text_to(
        self: "Self", report_name: "str", file_path: "str"
    ) -> None:
        """Method does not return.

        Args:
            report_name (str)
            file_path (str)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        pythonnet_method_call(
            self.wrapped,
            "OutputNamedReportAsTextTo",
            report_name if report_name else "",
            file_path if file_path else "",
        )

    @enforce_parameter_types
    def get_named_report_with_encoded_images(self: "Self", report_name: "str") -> "str":
        """str

        Args:
            report_name (str)
        """
        report_name = str(report_name)
        method_result = pythonnet_method_call(
            self.wrapped,
            "GetNamedReportWithEncodedImages",
            report_name if report_name else "",
        )
        return method_result

    @property
    def cast_to(self: "Self") -> "_Cast_SimpleNode":
        """Cast to another type.

        Returns:
            _Cast_SimpleNode
        """
        return _Cast_SimpleNode(self)
