"""SimpleThermalNode"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal import utility
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.python_net import python_net_import
from mastapy._private.nodal_analysis.lumped_parameter_thermal_analysis import _206

_SIMPLE_THERMAL_NODE = python_net_import(
    "SMT.MastaAPI.NodalAnalysis.LumpedParameterThermalAnalysis", "SimpleThermalNode"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.nodal_analysis.lumped_parameter_thermal_analysis import (
        _174,
        _175,
        _204,
        _221,
    )

    Self = TypeVar("Self", bound="SimpleThermalNode")
    CastSelf = TypeVar("CastSelf", bound="SimpleThermalNode._Cast_SimpleThermalNode")


__docformat__ = "restructuredtext en"
__all__ = ("SimpleThermalNode",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_SimpleThermalNode:
    """Special nested class for casting SimpleThermalNode to subclasses."""

    __parent__: "SimpleThermalNode"

    @property
    def simple_thermal_node_base(self: "CastSelf") -> "_206.SimpleThermalNodeBase":
        return self.__parent__._cast(_206.SimpleThermalNodeBase)

    @property
    def simple_node(self: "CastSelf") -> "_204.SimpleNode":
        from mastapy._private.nodal_analysis.lumped_parameter_thermal_analysis import (
            _204,
        )

        return self.__parent__._cast(_204.SimpleNode)

    @property
    def auto_generated_simple_fluid_thermal_node(
        self: "CastSelf",
    ) -> "_174.AutoGeneratedSimpleFluidThermalNode":
        from mastapy._private.nodal_analysis.lumped_parameter_thermal_analysis import (
            _174,
        )

        return self.__parent__._cast(_174.AutoGeneratedSimpleFluidThermalNode)

    @property
    def auto_generated_simple_thermal_node(
        self: "CastSelf",
    ) -> "_175.AutoGeneratedSimpleThermalNode":
        from mastapy._private.nodal_analysis.lumped_parameter_thermal_analysis import (
            _175,
        )

        return self.__parent__._cast(_175.AutoGeneratedSimpleThermalNode)

    @property
    def user_defined_simple_thermal_node(
        self: "CastSelf",
    ) -> "_221.UserDefinedSimpleThermalNode":
        from mastapy._private.nodal_analysis.lumped_parameter_thermal_analysis import (
            _221,
        )

        return self.__parent__._cast(_221.UserDefinedSimpleThermalNode)

    @property
    def simple_thermal_node(self: "CastSelf") -> "SimpleThermalNode":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class SimpleThermalNode(_206.SimpleThermalNodeBase):
    """SimpleThermalNode

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _SIMPLE_THERMAL_NODE

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def cast_to(self: "Self") -> "_Cast_SimpleThermalNode":
        """Cast to another type.

        Returns:
            _Cast_SimpleThermalNode
        """
        return _Cast_SimpleThermalNode(self)
